"""Pin definitions for the Binho Nova"""
from adafruit_blinka.microcontroller.nova import pin

IO0 = pin.IO0
IO1 = pin.IO1
IO2 = pin.IO2
IO3 = pin.IO3
IO4 = pin.IO4

TX = IO4
RX = IO3

SDA = pin.SDA
SCL = pin.SCL

SCK = pin.SCK
SCLK = pin.SCLK
MOSI = pin.MOSI
MISO = pin.MISO
SS0 = pin.SS0
SS1 = pin.SS1
