"""PyBoard pin names"""

from adafruit_blinka.microcontroller.stm32.stm32f405 import pin

X1 = pin.A0
X2 = pin.A1
X3 = pin.A2
X4 = pin.A3
X5 = pin.A4
X6 = pin.A5
X7 = pin.A6
X8 = pin.A7
X9 = pin.B6
X10 = pin.B7
X11 = pin.C4
X12 = pin.C5
X17 = pin.B3
X18 = pin.C13
X19 = pin.C0
X20 = pin.C1
X21 = pin.C2
X22 = pin.C3
Y1 = pin.C6
Y2 = pin.C7
Y3 = pin.B8
Y4 = pin.B9
Y5 = pin.B12
Y6 = pin.B13
Y7 = pin.B14
Y8 = pin.B15
Y9 = pin.B10
Y10 = pin.B11
Y11 = pin.B0
Y12 = pin.B1
SW = pin.B3
LED_RED = pin.A13
LED_GREEN = pin.A14
LED_YELLOW = pin.A15
LED_BLUE = pin.B4
MMA_INT = pin.B2
MMA_AVDD = pin.B5
SD_D0 = pin.C8
SD_D1 = pin.C9
SD_D2 = pin.C10
SD_D3 = pin.C11
SD_CMD = pin.D2
SD_CK = pin.C12
SD = pin.A8
SD_SW = pin.A8
USB_VBUS = pin.A9
USB_ID = pin.A10
USB_DM = pin.A11
USB_DP = pin.A12
