"""Pin definitions for the Odroid C2."""

from adafruit_blinka.microcontroller.amlogic.s905 import pin

GPIOX_0 = pin.GPIO228
GPIOX_1 = pin.GPIO229
GPIOX_2 = pin.GPIO230
GPIOX_3 = pin.GPIO231
GPIOX_4 = pin.GPIO232
GPIOX_5 = pin.GPIO233
GPIOX_6 = pin.GPIO234
GPIOX_7 = pin.GPIO235
GPIOX_8 = pin.GPIO236
GPIOX_9 = pin.GPIO237
GPIOX_10 = pin.GPIO238
GPIOX_11 = pin.GPIO239
GPIOX_12 = pin.GPIO240
GPIOX_13 = pin.GPIO241
GPIOX_19 = pin.GPIO247
GPIOX_21 = pin.GPIO249

GPIODV_24 = pin.GPIO205
GPIODV_25 = pin.GPIO206
GPIODV_26 = pin.GPIO207
GPIODV_27 = pin.GPIO208
GPIODV_28 = pin.GPIO209
GPIODV_29 = pin.GPIO210

GPIOY_0 = pin.GPIO211
GPIOY_1 = pin.GPIO212
GPIOY_3 = pin.GPIO214
GPIOY_7 = pin.GPIO218
GPIOY_8 = pin.GPIO219
GPIOY_12 = pin.GPIO223
GPIOY_13 = pin.GPIO224
GPIOY_14 = pin.GPIO225

GPIOA0_0 = pin.GPIO122
GPIOA0_1 = pin.GPIO123
GPIOA0_2 = pin.GPIO124
GPIOA0_3 = pin.GPIO125
GPIOA0_4 = pin.GPIO126
GPIOA0_5 = pin.GPIO127
GPIOA0_6 = pin.GPIO128
GPIOA0_7 = pin.GPIO129
GPIOA0_8 = pin.GPIO130
GPIOA0_9 = pin.GPIO131
GPIOA0_10 = pin.GPIO132
GPIOA0_11 = pin.GPIO133
GPIOA0_12 = pin.GPIO134
GPIOA0_13 = pin.GPIO135

SDA = pin.I2C0_SDA
SCL = pin.I2C0_SCL

SCLK = pin.SPI0_SCLK
MOSI = pin.SPI0_MOSI
MISO = pin.SPI0_MISO
SPI_CS0 = pin.GPIO229
SPI_CS1 = pin.GPIO225

D0 = GPIOX_19
D1 = GPIOX_10
D2 = GPIOX_11
D3 = GPIOX_9
D4 = GPIOX_8
D5 = GPIOX_5
D6 = GPIOX_3
D7 = GPIOX_21
D10 = GPIOX_1
D11 = GPIOY_14
D12 = GPIOX_7
D13 = GPIOX_4
D14 = GPIOX_2
D21 = GPIOX_0
D22 = GPIOY_8
D23 = GPIOX_6
D24 = GPIOY_3
D26 = GPIOY_13
D27 = GPIOY_7
