"""Pin definitions for Jetson TX2."""

from adafruit_blinka.microcontroller.tegra.t186 import pin

SDA = pin.SDA
SCL = pin.SCL
SDA_1 = pin.SDA_1
SCL_1 = pin.SCL_1

D4 = pin.J04
D5 = pin.J06
D6 = pin.AA02
D7 = None
D8 = pin.N06
D9 = pin.N04
D10 = pin.N05
D11 = pin.N03
D12 = pin.AA01
D13 = pin.I05
D16 = pin.T03
D17 = pin.T02
D18 = pin.J00
D19 = pin.J03
D20 = pin.J02
D21 = pin.J01
D22 = pin.P17
D23 = pin.AA00
D24 = pin.Y01
D25 = pin.P16
D26 = pin.I04
D27 = pin.J05

CE1 = None
CE0 = D8
MISO = D9
MOSI = D10
SCLK = D11
SCK = D11
