"""Pin definitions for Jetson NX."""

from adafruit_blinka.microcontroller.tegra.t194 import pin

SDA = pin.SDA
SCL = pin.SCL
SDA_1 = pin.SDA_1
SCL_1 = pin.SCL_1

D4 = pin.S04
D5 = pin.Q05
D6 = pin.Q06
D7 = pin.Z07
D8 = pin.Z06
D9 = pin.Z04
D10 = pin.Z05
D11 = pin.Z03
D12 = pin.R00
D13 = pin.N01
D16 = pin.R05
D17 = pin.R04
D18 = pin.T05
D19 = pin.U00
D20 = pin.T07
D21 = pin.T06
D22 = pin.CC04
D23 = pin.Y04
D24 = pin.Y03
D25 = pin.Y01
D26 = pin.Y02
D27 = pin.Y00

CE1 = D7
CE0 = D8
MISO = D9
MOSI = D10
SCLK = D11
SCK = D11
