"""Pin definitions for the Raspberry Pi Model B Revision 1."""

from adafruit_blinka.microcontroller.bcm283x import pin

D0 = pin.D0
D1 = pin.D1
SDA = pin.D0
SCL = pin.D1
D4 = pin.D4

D7 = pin.D7
CE1 = pin.D7
D8 = pin.D8
CE0 = pin.D8
D9 = pin.D9
MISO = pin.D9
D10 = pin.D10
MOSI = pin.D10
D11 = pin.D11
SCLK = pin.D11
SCK = pin.D11

D14 = pin.D14
TXD = pin.D14
D15 = pin.D15
RXD = pin.D15
# create alias for most of the examples
TX = pin.D14
RX = pin.D15

D17 = pin.D17
D18 = pin.D18
D21 = pin.D21
D22 = pin.D22
D23 = pin.D23
D24 = pin.D24
D25 = pin.D25
