"""Pin definitions for the FTDI FT232H"""
from adafruit_blinka.microcontroller.ft232h import pin

D4 = pin.D4
D5 = pin.D5
D6 = pin.D6
D7 = pin.D7
C0 = pin.C0
C1 = pin.C1
C2 = pin.C2
C3 = pin.C3
C4 = pin.C4
C5 = pin.C5
C6 = pin.C6
C7 = pin.C7

SDA = pin.SDA
SCL = pin.SCL

SCK = pin.SCK
SCLK = pin.SCLK
MOSI = pin.MOSI
MISO = pin.MISO
