"""Pin definitions for the Orange Pi Zero 2."""

from adafruit_blinka.microcontroller.allwinner.h616 import pin

PH5 = pin.PH5
SDA = pin.PH5
PH4 = pin.PH4
SCL = pin.PH4
PC9 = pin.PC9

PH3 = pin.PH3
UART5_RX = pin.PH3
PH2 = pin.PH2
UART5_TX = pin.PH2
PC8 = pin.PC8

PC10 = pin.PC10
PC11 = pin.PC11
PC6 = pin.PC6
PC5 = pin.PC5

PH9 = pin.PH9
SPI1_CS = pin.PH9
PH6 = pin.PH6
SPI1_CLK = pin.PH6
PC7 = pin.PC7

PC14 = pin.PC14

PC15 = pin.PC15


SCLK = pin.PH6
MOSI = pin.PH7
MISO = pin.PH8
