"""Pin definitions for the Orange Pi PC."""

from adafruit_blinka.microcontroller.allwinner.h3 import pin

PA12 = pin.PA12
SDA = pin.PA12
PA11 = pin.PA11
SCL = pin.PA11
PA6 = pin.PA6
PA1 = pin.PA1
PA0 = pin.PA0
PA3 = pin.PA3
PC0 = pin.PC0
MOSI = pin.PC0
MOSI1 = pin.SPI1_MOSI
PC1 = pin.PC1
MISO = pin.PC1
PC2 = pin.PC2
SCK = pin.PC2
SCK1 = pin.SPI1_SCLK
SCLK = pin.PC2
PA19 = pin.PA19
PA7 = pin.PA7
PA8 = pin.PA8
PA9 = pin.PA9
PA10 = pin.PA10
PA20 = pin.PA20

PA13 = pin.PA13
TX = pin.PA13
PA14 = pin.PA14
RX = pin.PA14
PD14 = pin.PD14
PC4 = pin.PC4
PC7 = pin.PC7
PA2 = pin.PA2
PC3 = pin.PC3
PA21 = pin.PA21
PA18 = pin.PA18
PG8 = pin.PG8
PG9 = pin.PG9
PG6 = pin.PG6
PG7 = pin.PG7
