"""Pin definitions for Clara AGX Xavier."""

from adafruit_blinka.microcontroller.tegra.t194 import pin

SDA = pin.SDA
SCL = pin.SCL
SDA_1 = pin.SDA_1
SCL_1 = pin.SCL_1

D4 = pin.Q06
D5 = pin.AA03
D6 = pin.AA02
D7 = pin.Z07
D8 = pin.Z06
D9 = pin.Z04
D10 = pin.Z05
D11 = pin.Z03
D12 = pin.BB01
D13 = pin.AA00
D16 = pin.R05
D17 = pin.R04
D18 = pin.H07
D19 = pin.I02
D20 = pin.I01
D21 = pin.I00
D22 = pin.N01
D23 = pin.BB00
D24 = pin.H00
D25 = pin.Q01
D26 = pin.AA01
D27 = pin.P04

CE1 = D7
CE0 = D8
MISO = D9
MOSI = D10
SCLK = D11
SCK = D11
