"""Pin definitions for the Tritium H3."""

from adafruit_blinka.microcontroller.allwinner.h3 import pin

PA12 = pin.PA12
SDA = pin.PA12
PA11 = pin.PA11
SCL = pin.PA11
PA2 = pin.PA2
PA1 = pin.PA1
PA0 = pin.PA0
PA3 = pin.PA3
PC0 = pin.PC0
MOSI = pin.PC0
PC1 = pin.PC1
MISO = pin.PC1
PC2 = pin.PC2
SCK = pin.PC2
SCLK = pin.PC2
PA19 = pin.PA19
PA20 = pin.PA20
PA21 = pin.PA21
PA6 = pin.PA6
PG10 = pin.PG10
PA16 = pin.PA16

PG6 = pin.PG6
TX = pin.PG6
PG7 = pin.PG7
RX = pin.PG7
PG11 = pin.PG11
PG9 = pin.PG9
PG8 = pin.PG8
PA14 = pin.PA14
PC3 = pin.PC3
PA17 = pin.PA17
PA18 = pin.PA18
PA13 = pin.PA13
PA15 = pin.PA15
PG13 = pin.PG13
PG12 = pin.PG12
