"""Pin definitions for Jetson Nano."""

from adafruit_blinka.microcontroller.tegra.t210 import pin

SDA = pin.SDA_1
SCL = pin.SCL_1
SDA_1 = pin.SDA
SCL_1 = pin.SCL

D4 = pin.BB00
D5 = pin.S05
D6 = pin.Z00
D7 = pin.C04
D8 = pin.C03
D9 = pin.C01
D10 = pin.C00
D11 = pin.C02
D12 = pin.V00
D13 = pin.E06
D16 = pin.G03
D17 = pin.G02
D18 = pin.J07
D19 = pin.J04
D20 = pin.J05
D21 = pin.J06
D22 = pin.Y02
D23 = pin.DD00
D24 = pin.B07
D25 = pin.B05
D26 = pin.B04
D27 = pin.B06

CE1 = D7
CE0 = D8
MISO = D9
MOSI = D10
SCLK = D11
SCK = D11

CE1_1 = D23
CE0_1 = D24
MISO_1 = D25
MOSI_1 = D26
SCLK_1 = D27
SCK_1 = D27
