"""Pin definitions for Jetson TX1."""

from adafruit_blinka.microcontroller.tegra.t210 import pin

SDA = pin.SDA
SCL = pin.SCL
SDA_1 = pin.SDA_1
SCL_1 = pin.SCL_1

D4 = pin.BB00
D5 = pin.BB03
D6 = pin.X02
D7 = pin.C04
D8 = pin.C03
D9 = pin.C01
D10 = pin.C00
D11 = pin.C02
D12 = pin.E04
D13 = pin.H07
D16 = pin.U03
D17 = pin.U02
D18 = pin.B03
D19 = pin.B00
D20 = pin.B01
D21 = pin.B02
D22 = pin.P17
D23 = pin.E05
D24 = pin.X00
D25 = pin.P16
D26 = pin.X03
D27 = pin.E06

CE1 = D7
CE0 = D8
MISO = D9
MOSI = D10
SCLK = D11
SCK = D11
